package com.example.ftptest.internal;

import org.apache.camel.CamelContext;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.impl.DefaultCamelContext;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

public class Activator implements BundleActivator {

    CamelContext camelContext = new DefaultCamelContext();
	@Override
	public void start(BundleContext context) throws Exception {
	    try {
		RouteBuilder routeBuilder = createRouteBuilder();
		camelContext.addRoutes(routeBuilder);
		camelContext.start();
	    } catch (Exception e) {
		e.printStackTrace();
		throw e;
	    }
	}

	@Override
	public void stop(BundleContext context) throws Exception {
	}

	
	protected RouteBuilder createRouteBuilder() throws Exception {
	    return new RouteBuilder() {
	        public void configure() throws Exception {
	            // we use a delay of 60 minutes (eg. once pr. hour we poll the FTP server
	            long delay = 30 * 1000L;

	            // from the given FTP server we poll (= download) all the files
	            // from the public/reports folder as BINARY types and store this as files
	            // in a local directory. Camel will use the filenames from the FTPServer

	            // notice that the FTPConsumer properties must be prefixed with "consumer." in the URL
	            // the delay parameter is from the FileConsumer component so we should use consumer.delay as
	            // the URI parameter name. The FTP Component is an extension of the File Component.
	            from("ftp://joe@localhost/tmp/test.txt?password=joe1234&binary=false&consumer.delay=" + delay).
	                    to("file://target/test-reports");
	        }
	    };
	}

}
